@@ -55,6 +55,8 @@
 #define USERAGENT             "Evolution/" VERSION
 #define WEBDAV_CLOSURE_NAME   "EBookBackendWebdav.BookView::closure"
 
+G_DEFINE_TYPE (EBookBackendWebdav, e_book_backend_webdav, E_TYPE_BOOK_BACKEND)
+
 static EBookBackendClass *parent_class;
 
 struct _EBookBackendWebdavPrivate {
@@ -289,7 +291,7 @@ e_book_backend_webdav_create_contact(EBookBackend *backend,
 		return;
 	}
 	/* PUT request didn't return an etag? try downloading to get one */
-	if(e_contact_get_const(contact, E_CONTACT_REV) == NULL) {
+	if (e_contact_get_const(contact, E_CONTACT_REV) == NULL) {
 		EContact *new_contact;
 
 		g_warning("Server didn't return etag for new address resource");
@@ -418,12 +420,12 @@ e_book_backend_webdav_modify_contact(EBookBackend *backend,
 	etag = e_contact_get_const(contact, E_CONTACT_REV);
 
 	/* PUT request didn't return an etag? try downloading to get one */
-	if(etag == NULL || (etag[0] == 'W' && etag[1] == '/')) {
+	if (etag == NULL || (etag[0] == 'W' && etag[1] == '/')) {
 		EContact *new_contact;
 
 		g_warning("Server didn't return etag for modified address resource");
 		new_contact = download_contact(webdav, uid);
-		if(new_contact != NULL) {
+		if (new_contact != NULL) {
 			contact = new_contact;
 		}
 	}
@@ -1058,7 +1060,8 @@ e_book_backend_webdav_remove(EBookBackend *backend,	EDataBook *book,
 }
 
 static void
-e_book_backend_webdav_set_mode(EBookBackend *backend, gint mode)
+e_book_backend_webdav_set_mode(EBookBackend *backend,
+                               GNOME_Evolution_Addressbook_BookMode mode)
 {
 	EBookBackendWebdav *webdav = E_BOOK_BACKEND_WEBDAV(backend);
 
@@ -1165,27 +1168,3 @@ e_book_backend_webdav_init(EBookBackendWebdav *backend)
 			E_TYPE_BOOK_BACKEND_WEBDAV, EBookBackendWebdavPrivate);
 }
 
-GType
-e_book_backend_webdav_get_type(void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo info = {
-			sizeof(EBookBackendWebdavClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_book_backend_webdav_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof(EBookBackendWebdav),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_book_backend_webdav_init
-		};
-
-		type = g_type_register_static(E_TYPE_BOOK_BACKEND, "EBookBackendWebdav",
-				&info, 0);
-	}
-
-	return type;
-}
