@@ -28,8 +28,10 @@
 
 #include <config.h>
 
-#include <string.h>
+#include <ctype.h>
+#include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
@@ -392,13 +394,58 @@ cdb_sql_exec (sqlite3 *db, const gchar * stmt, CamelException *ex)
 	return 0;
 }
 
+/* checks whether string 'where' contains whole word 'what',
+   case insensitively (ascii, not utf8, same as 'LIKE' in SQLite3)
+*/
+static void
+cdb_match_func (sqlite3_context *ctx, int nArgs, sqlite3_value **values)
+{
+	gboolean matches = FALSE;
+	const gchar *what, *where;
+
+	g_return_if_fail (ctx != NULL);
+	g_return_if_fail (nArgs == 2);
+	g_return_if_fail (values != NULL);
+
+	what = (const gchar *) sqlite3_value_text (values[0]);
+	where = (const gchar *) sqlite3_value_text (values[1]);
+
+	if (what && where && !*what) {
+		matches = TRUE;
+	} else if (what && where) {
+		gboolean word = TRUE;
+		gint i, j;
+
+		for (i = 0, j = 0; where[i] && !matches; i++) {
+			char c = where[i];
+
+			if (c == ' ') {
+				word = TRUE;
+				j = 0;
+			} else if (word && tolower (c) == tolower(what[j])) {
+				j++;
+				if (what[j] == 0 && (where[i + 1] == 0 || isspace (where[i + 1])))
+					matches = TRUE;
+			} else {
+				word = FALSE;
+			}
+		}
+	}
+
+	sqlite3_result_int (ctx, matches ? 1 : 0);
+}
+
+/**
+ * camel_db_open:
+ *
+ * Since: 2.24
+ **/
 CamelDB *
 camel_db_open (const gchar *path, CamelException *ex)
 {
 	static GOnce vfs_once = G_ONCE_INIT;
 	CamelDB *cdb;
 	sqlite3 *db;
-	gchar *cache;
 	gint ret;
 
 	g_once (&vfs_once, (GThreadFunc) init_sqlite_vfs, NULL);
@@ -428,14 +475,16 @@ camel_db_open (const gchar *path, CamelException *ex)
 	cdb->priv->timer = NULL;
 	d(g_print ("\nDatabase succesfully opened  \n"));
 
-	/* Which is big / costlier ? A Stack frame or a pointer */
-	if (g_getenv("CAMEL_SQLITE_DEFAULT_CACHE_SIZE")!=NULL)
-		cache = g_strdup_printf ("PRAGMA cache_size=%s", g_getenv("CAMEL_SQLITE_DEFAULT_CACHE_SIZE"));
-	else
-		cache = g_strdup ("PRAGMA cache_size=100");
+	sqlite3_create_function (db, "MATCH", 2, SQLITE_UTF8, NULL, cdb_match_func, NULL, NULL);
 
-	camel_db_command (cdb, cache, NULL);
-	g_free (cache);
+	/* Which is big / costlier ? A Stack frame or a pointer */
+	if (g_getenv("CAMEL_SQLITE_DEFAULT_CACHE_SIZE")!=NULL) {
+		gchar *cache = NULL;
+
+		cache = g_strdup_printf ("PRAGMA cache_size=%s", g_getenv("CAMEL_SQLITE_DEFAULT_CACHE_SIZE"));
+		camel_db_command (cdb, cache, NULL);
+		g_free (cache);
+	}
 
 	camel_db_command (cdb, "ATTACH DATABASE ':memory:' AS mem", NULL);
 
@@ -450,12 +499,22 @@ camel_db_open (const gchar *path, CamelException *ex)
 	return cdb;
 }
 
+/**
+ * camel_db_clone:
+ *
+ * Since: 2.26
+ **/
 CamelDB *
 camel_db_clone (CamelDB *cdb, CamelException *ex)
 {
 	return camel_db_open(cdb->priv->file_name, ex);
 }
 
+/**
+ * camel_db_close:
+ *
+ * Since: 2.24
+ **/
 void
 camel_db_close (CamelDB *cdb)
 {
@@ -467,6 +526,11 @@ camel_db_close (CamelDB *cdb)
 	}
 }
 
+/**
+ * camel_db_set_collate:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_set_collate (CamelDB *cdb, const gchar *col, const gchar *collate, CamelDBCollate func)
 {
@@ -484,24 +548,35 @@ camel_db_set_collate (CamelDB *cdb, const gchar *col, const gchar *collate, Came
 		return ret;
 }
 
-/* Should this be really exposed ? */
+/**
+ * camel_db_command:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_command (CamelDB *cdb, const gchar *stmt, CamelException *ex)
 {
-		gint ret;
+	gint ret;
 
-		if (!cdb)
-			return TRUE;
-		g_mutex_lock (cdb->lock);
+	/* XXX Should this be really exposed ? */
 
-		START(stmt);
-		ret = cdb_sql_exec (cdb->db, stmt, ex);
-		END;
-		g_mutex_unlock (cdb->lock);
+	if (!cdb)
+		return TRUE;
+	g_mutex_lock (cdb->lock);
 
-		return ret;
+	START(stmt);
+	ret = cdb_sql_exec (cdb->db, stmt, ex);
+	END;
+	g_mutex_unlock (cdb->lock);
+
+	return ret;
 }
 
+/**
+ * camel_db_begin_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_begin_transaction (CamelDB *cdb, CamelException *ex)
 {
@@ -516,6 +591,11 @@ camel_db_begin_transaction (CamelDB *cdb, CamelException *ex)
 	return (cdb_sql_exec (cdb->db, "BEGIN", ex));
 }
 
+/**
+ * camel_db_end_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_end_transaction (CamelDB *cdb, CamelException *ex)
 {
@@ -534,6 +614,11 @@ camel_db_end_transaction (CamelDB *cdb, CamelException *ex)
 	return ret;
 }
 
+/**
+ * camel_db_abort_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_abort_transaction (CamelDB *cdb, CamelException *ex)
 {
@@ -548,6 +633,11 @@ camel_db_abort_transaction (CamelDB *cdb, CamelException *ex)
 	return ret;
 }
 
+/**
+ * camel_db_add_to_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_add_to_transaction (CamelDB *cdb, const gchar *stmt, CamelException *ex)
 {
@@ -557,6 +647,11 @@ camel_db_add_to_transaction (CamelDB *cdb, const gchar *stmt, CamelException *ex
 	return (cdb_sql_exec (cdb->db, stmt, ex));
 }
 
+/**
+ * camel_db_transaction_command:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_transaction_command (CamelDB *cdb, GSList *qry_list, CamelException *ex)
 {
@@ -601,6 +696,11 @@ count_cb (gpointer data, gint argc, gchar **argv, gchar **azColName)
 	return 0;
 }
 
+/**
+ * camel_db_count_message_info:
+ *
+ * Since: 2.26
+ **/
 gint
 camel_db_count_message_info (CamelDB *cdb, const gchar *query, guint32 *count, CamelException *ex)
 {
@@ -642,6 +742,11 @@ camel_db_count_message_info (CamelDB *cdb, const gchar *query, guint32 *count, C
 	return ret;
 }
 
+/**
+ * camel_db_count_junk_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_junk_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -659,6 +764,11 @@ camel_db_count_junk_message_info (CamelDB *cdb, const gchar *table_name, guint32
 	return ret;
 }
 
+/**
+ * camel_db_count_unread_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_unread_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -676,6 +786,11 @@ camel_db_count_unread_message_info (CamelDB *cdb, const gchar *table_name, guint
 	return ret;
 }
 
+/**
+ * camel_db_count_visible_unread_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_visible_unread_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -693,6 +808,11 @@ camel_db_count_visible_unread_message_info (CamelDB *cdb, const gchar *table_nam
 	return ret;
 }
 
+/**
+ * camel_db_count_visible_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_visible_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -710,6 +830,11 @@ camel_db_count_visible_message_info (CamelDB *cdb, const gchar *table_name, guin
 	return ret;
 }
 
+/**
+ * camel_db_count_junk_not-deleted_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_junk_not_deleted_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -727,6 +852,11 @@ camel_db_count_junk_not_deleted_message_info (CamelDB *cdb, const gchar *table_n
 	return ret;
 }
 
+/**
+ * camel_db_count_deleted_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_deleted_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -744,6 +874,11 @@ camel_db_count_deleted_message_info (CamelDB *cdb, const gchar *table_name, guin
 	return ret;
 }
 
+/**
+ * camel_db_count_total_message_info:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_count_total_message_info (CamelDB *cdb, const gchar *table_name, guint32 *count, CamelException *ex)
 {
@@ -762,6 +897,11 @@ camel_db_count_total_message_info (CamelDB *cdb, const gchar *table_name, guint3
 	return ret;
 }
 
+/**
+ * camel_db_select:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_select (CamelDB *cdb, const gchar * stmt, CamelDBSelectCB callback, gpointer data, CamelException *ex)
 {
@@ -807,6 +947,11 @@ camel_db_select (CamelDB *cdb, const gchar * stmt, CamelDBSelectCB callback, gpo
 	return ret;
 }
 
+/**
+ * camel_db_create_vfolder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_create_vfolder (CamelDB *db, const gchar *folder_name, CamelException *ex)
 {
@@ -830,6 +975,11 @@ camel_db_create_vfolder (CamelDB *db, const gchar *folder_name, CamelException *
 	return ret;
 }
 
+/**
+ * camel_db_recreate_vfolder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_recreate_vfolder (CamelDB *db, const gchar *folder_name, CamelException *ex)
 {
@@ -845,6 +995,11 @@ camel_db_recreate_vfolder (CamelDB *db, const gchar *folder_name, CamelException
 	return camel_db_create_vfolder (db, folder_name, ex);
 }
 
+/**
+ * camel_db_delete_uid_from_vfolder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_delete_uid_from_vfolder (CamelDB *db, gchar *folder_name, gchar *vuid, CamelException *ex)
 {
@@ -860,6 +1015,11 @@ camel_db_delete_uid_from_vfolder (CamelDB *db, gchar *folder_name, gchar *vuid,
 	 return ret;
 }
 
+/**
+ * camel_db_delete_uid_from_vfolder_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_delete_uid_from_vfolder_transaction (CamelDB *db, const gchar *folder_name, const gchar *vuid, CamelException *ex)
 {
@@ -895,6 +1055,11 @@ read_uids_flags_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 	 return 0;
 }
 
+/**
+ * camel_db_get_folder_uids_flags:
+ *
+ * Since: 2.26
+ **/
 gint
 camel_db_get_folder_uids_flags (CamelDB *db, const gchar *folder_name, const gchar *sort_by, const gchar *collate, GPtrArray *summary, GHashTable *table, CamelException *ex)
 {
@@ -939,6 +1104,11 @@ read_uids_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 	 return 0;
 }
 
+/**
+ * camel_db_get_folder_uids:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_get_folder_uids (CamelDB *db, const gchar *folder_name, const gchar *sort_by, const gchar *collate, GPtrArray *array, CamelException *ex)
 {
@@ -953,6 +1123,11 @@ camel_db_get_folder_uids (CamelDB *db, const gchar *folder_name, const gchar *so
 	 return ret;
 }
 
+/**
+ * camel_db_get_folder_junk_uids:
+ *
+ * Since: 2.24
+ **/
 GPtrArray *
 camel_db_get_folder_junk_uids (CamelDB *db, gchar *folder_name, CamelException *ex)
 {
@@ -973,6 +1148,11 @@ camel_db_get_folder_junk_uids (CamelDB *db, gchar *folder_name, CamelException *
 	 return array;
 }
 
+/**
+ * camel_db_get_folder_deleted_uids:
+ *
+ * Since: 2.24
+ **/
 GPtrArray *
 camel_db_get_folder_deleted_uids (CamelDB *db, gchar *folder_name, CamelException *ex)
 {
@@ -1013,6 +1193,11 @@ read_preview_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 	return 0;
 }
 
+/**
+ * camel_db_get_folder_preview:
+ *
+ * Since: 2.28
+ **/
 GHashTable *
 camel_db_get_folder_preview (CamelDB *db, gchar *folder_name, CamelException *ex)
 {
@@ -1020,7 +1205,7 @@ camel_db_get_folder_preview (CamelDB *db, gchar *folder_name, CamelException *ex
 	 gint ret;
 	 GHashTable *hash = g_hash_table_new (g_str_hash, g_str_equal);
 
-	 sel_query = sqlite3_mprintf("SELECT uid, preview FROM '%s_preview'", folder_name);
+	 sel_query = sqlite3_mprintf("SELECT uid, preview FROM '%q_preview'", folder_name);
 
 	 ret = camel_db_select (db, sel_query, read_preview_callback, hash, ex);
 	 sqlite3_free (sel_query);
@@ -1033,13 +1218,18 @@ camel_db_get_folder_preview (CamelDB *db, gchar *folder_name, CamelException *ex
 	 return hash;
 }
 
+/**
+ * camel_db_write_preview_record:
+ *
+ * Since: 2.28
+ **/
 gint
 camel_db_write_preview_record (CamelDB *db, gchar *folder_name, const gchar *uid, const gchar *msg, CamelException *ex)
 {
 	gchar *query;
 	gint ret;
 
-	query = sqlite3_mprintf("INSERT OR REPLACE INTO '%s_preview' VALUES(%Q,%Q)", folder_name, uid, msg);
+	query = sqlite3_mprintf("INSERT OR REPLACE INTO '%q_preview' VALUES(%Q,%Q)", folder_name, uid, msg);
 
 	ret = camel_db_add_to_transaction (db, query, ex);
 	sqlite3_free (query);
@@ -1066,6 +1256,11 @@ read_vuids_callback (gpointer ref, gint ncol, gchar ** cols, gchar ** name)
 	 return 0;
 }
 
+/**
+ * camel_db_get_vuids_from_vfolder:
+ *
+ * Since: 2.24
+ **/
 GPtrArray *
 camel_db_get_vuids_from_vfolder (CamelDB *db, gchar *folder_name, gchar *filter, CamelException *ex)
 {
@@ -1095,6 +1290,11 @@ camel_db_get_vuids_from_vfolder (CamelDB *db, gchar *folder_name, gchar *filter,
 	 return array;
 }
 
+/**
+ * camel_db_add_to_vfolder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_add_to_vfolder (CamelDB *db, gchar *folder_name, gchar *vuid, CamelException *ex)
 {
@@ -1110,8 +1310,13 @@ camel_db_add_to_vfolder (CamelDB *db, gchar *folder_name, gchar *vuid, CamelExce
 	 return ret;
 }
 
+/**
+ * camel_db_add_to_vfolder_transaction:
+ *
+ * Since: 2.24
+ **/
 gint
-camel_db_add_to_vfolder_transaction (CamelDB *db, gchar *folder_name, gchar *vuid, CamelException *ex)
+camel_db_add_to_vfolder_transaction (CamelDB *db, const gchar *folder_name, const gchar *vuid, CamelException *ex)
 {
 	 gchar *ins_query;
 	 gint ret;
@@ -1125,6 +1330,11 @@ camel_db_add_to_vfolder_transaction (CamelDB *db, gchar *folder_name, gchar *vui
 	 return ret;
 }
 
+/**
+ * camel_db_create_folders_table:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_create_folders_table (CamelDB *cdb, CamelException *ex)
 {
@@ -1144,12 +1354,12 @@ camel_db_create_message_info_table (CamelDB *cdb, const gchar *folder_name, Came
 	ret = camel_db_add_to_transaction (cdb, table_creation_query, ex);
 	sqlite3_free (table_creation_query);
 
-	table_creation_query = sqlite3_mprintf ("CREATE TABLE IF NOT EXISTS '%s_bodystructure' (  uid TEXT PRIMARY KEY , bodystructure TEXT )", folder_name);
+	table_creation_query = sqlite3_mprintf ("CREATE TABLE IF NOT EXISTS '%q_bodystructure' (  uid TEXT PRIMARY KEY , bodystructure TEXT )", folder_name);
 	ret = camel_db_add_to_transaction (cdb, table_creation_query, ex);
 	sqlite3_free (table_creation_query);
 
 	/* Create message preview table. */
-	table_creation_query = sqlite3_mprintf ("CREATE TABLE IF NOT EXISTS '%s_preview' (  uid TEXT PRIMARY KEY , preview TEXT)", folder_name);
+	table_creation_query = sqlite3_mprintf ("CREATE TABLE IF NOT EXISTS '%q_preview' (  uid TEXT PRIMARY KEY , preview TEXT)", folder_name);
 	ret = camel_db_add_to_transaction (cdb, table_creation_query, ex);
 	sqlite3_free (table_creation_query);
 
@@ -1162,7 +1372,7 @@ camel_db_create_message_info_table (CamelDB *cdb, const gchar *folder_name, Came
 
 	/* INDEX on preview */
 	safe_index = g_strdup_printf("SINDEX-%s-preview", folder_name);
-	table_creation_query = sqlite3_mprintf ("CREATE INDEX IF NOT EXISTS %Q ON '%s_preview' (uid, preview)", safe_index, folder_name);
+	table_creation_query = sqlite3_mprintf ("CREATE INDEX IF NOT EXISTS %Q ON '%q_preview' (uid, preview)", safe_index, folder_name);
 	ret = camel_db_add_to_transaction (cdb, table_creation_query, ex);
 	g_free (safe_index);
 	sqlite3_free (table_creation_query);
@@ -1255,6 +1465,11 @@ camel_db_migrate_folder_recreate (CamelDB *cdb, const gchar *folder_name, gint v
 	return ret;
 }
 
+/**
+ * camel_db_reset_folder_version:
+ *
+ * Since: 2.28
+ **/
 gint
 camel_db_reset_folder_version (CamelDB *cdb, const gchar *folder_name, gint reset_version, CamelException *ex)
 {
@@ -1325,6 +1540,11 @@ camel_db_get_folder_version (CamelDB *cdb, const gchar *folder_name, CamelExcept
 	return version;
 }
 
+/**
+ * camel_db_prepare_message_info_table:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_prepare_message_info_table (CamelDB *cdb, const gchar *folder_name, CamelException *ex)
 {
@@ -1348,12 +1568,22 @@ camel_db_prepare_message_info_table (CamelDB *cdb, const gchar *folder_name, Cam
 	return ret;
 }
 
+/**
+ * camel_db_write_fresh_message_info_record:
+ *
+ * Since: 2.26
+ **/
 gint
 camel_db_write_fresh_message_info_record (CamelDB *cdb, const gchar *folder_name, CamelMIRecord *record, CamelException *ex)
 {
 	return write_mir (cdb, folder_name, record, ex, FALSE);
 }
 
+/**
+ * camel_db_write_message_info_record:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_write_message_info_record (CamelDB *cdb, const gchar *folder_name, CamelMIRecord *record, CamelException *ex)
 {
@@ -1404,7 +1634,7 @@ write_mir (CamelDB *cdb, const gchar *folder_name, CamelMIRecord *record, CamelE
 	sqlite3_free (ins_query);
 
 	if (ret == 0) {
-		ins_query = sqlite3_mprintf ("INSERT OR REPLACE INTO '%s_bodystructure' VALUES (%Q, %Q )",
+		ins_query = sqlite3_mprintf ("INSERT OR REPLACE INTO '%q_bodystructure' VALUES (%Q, %Q )",
 				folder_name, record->uid, record->bodystructure);
 		ret = camel_db_add_to_transaction (cdb, ins_query, ex);
 		sqlite3_free (ins_query);
@@ -1413,6 +1643,11 @@ write_mir (CamelDB *cdb, const gchar *folder_name, CamelMIRecord *record, CamelE
 	return ret;
 }
 
+/**
+ * camel_db_write_folder_info_record:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_write_folder_info_record (CamelDB *cdb, CamelFIRecord *record, CamelException *ex)
 {
@@ -1501,6 +1736,11 @@ read_fir_callback (gpointer  ref, gint ncol, gchar ** cols, gchar ** name)
 	return 0;
 }
 
+/**
+ * camel_db_read_folder_info_record:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_read_folder_info_record (CamelDB *cdb, const gchar *folder_name, CamelFIRecord **record, CamelException *ex)
 {
@@ -1514,6 +1754,11 @@ camel_db_read_folder_info_record (CamelDB *cdb, const gchar *folder_name, CamelF
 	return (ret);
 }
 
+/**
+ * camel_db_read_message_info_record_with_uid:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_read_message_info_record_with_uid (CamelDB *cdb, const gchar *folder_name, const gchar *uid, gpointer p, CamelDBSelectCB read_mir_callback, CamelException *ex)
 {
@@ -1527,6 +1772,11 @@ camel_db_read_message_info_record_with_uid (CamelDB *cdb, const gchar *folder_na
 	return (ret);
 }
 
+/**
+ * camel_db_read_message_info_records:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_read_message_info_records (CamelDB *cdb, const gchar *folder_name, gpointer p, CamelDBSelectCB read_mir_callback, CamelException *ex)
 {
@@ -1540,6 +1790,11 @@ camel_db_read_message_info_records (CamelDB *cdb, const gchar *folder_name, gpoi
 	return (ret);
 }
 
+/**
+ * camel_db_create_deleted_table:
+ *
+ * Since: 2.24
+ **/
 static gint
 camel_db_create_deleted_table (CamelDB *cdb, CamelException *ex)
 {
@@ -1563,6 +1818,11 @@ camel_db_trim_deleted_table (CamelDB *cdb, CamelException *ex)
 	return ret;
 }
 
+/**
+ * camel_db_delete_uid:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_delete_uid (CamelDB *cdb, const gchar *folder, const gchar *uid, CamelException *ex)
 {
@@ -1579,7 +1839,7 @@ camel_db_delete_uid (CamelDB *cdb, const gchar *folder, const gchar *uid, CamelE
 
 	ret = camel_db_trim_deleted_table (cdb, ex);
 
-	tab = sqlite3_mprintf ("DELETE FROM '%s_bodystructure' WHERE uid = %Q", folder, uid);
+	tab = sqlite3_mprintf ("DELETE FROM '%q_bodystructure' WHERE uid = %Q", folder, uid);
 	ret = camel_db_add_to_transaction (cdb, tab, ex);
 	sqlite3_free (tab);
 
@@ -1664,6 +1924,11 @@ cdb_delete_ids (CamelDB *cdb, const gchar * folder_name, GSList *uids, const gch
 	return ret;
 }
 
+/**
+ * camel_db_delete_uids:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_delete_uids (CamelDB *cdb, const gchar * folder_name, GSList *uids, CamelException *ex)
 {
@@ -1673,12 +1938,22 @@ camel_db_delete_uids (CamelDB *cdb, const gchar * folder_name, GSList *uids, Cam
 	return cdb_delete_ids (cdb, folder_name, uids, "", "uid", ex);
 }
 
+/**
+ * camel_db_delete_vuids:
+ *
+ * Since: 2.26
+ **/
 gint
 camel_db_delete_vuids (CamelDB *cdb, const gchar * folder_name, const gchar *hash, GSList *uids, CamelException *ex)
 {
 	return cdb_delete_ids (cdb, folder_name, uids, hash, "vuid", ex);
 }
 
+/**
+ * camel_db_clear_folder_summary:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_clear_folder_summary (CamelDB *cdb, gchar *folder, CamelException *ex)
 {
@@ -1691,7 +1966,7 @@ camel_db_clear_folder_summary (CamelDB *cdb, gchar *folder, CamelException *ex)
 
 	folders_del = sqlite3_mprintf ("DELETE FROM folders WHERE folder_name = %Q", folder);
 	msginfo_del = sqlite3_mprintf ("DELETE FROM %Q ", folder);
-	bstruct_del = sqlite3_mprintf ("DELETE FROM '%s_bodystructure' ", folder);
+	bstruct_del = sqlite3_mprintf ("DELETE FROM '%q_bodystructure' ", folder);
 
 	camel_db_begin_transaction (cdb, ex);
 
@@ -1716,6 +1991,11 @@ camel_db_clear_folder_summary (CamelDB *cdb, gchar *folder, CamelException *ex)
 	return ret;
 }
 
+/**
+ * camel_db_delete_folder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_delete_folder (CamelDB *cdb, const gchar *folder, CamelException *ex)
 {
@@ -1741,7 +2021,7 @@ camel_db_delete_folder (CamelDB *cdb, const gchar *folder, CamelException *ex)
 	ret = camel_db_add_to_transaction (cdb, del, ex);
 	sqlite3_free (del);
 
-	del = sqlite3_mprintf ("DROP TABLE '%s_bodystructure' ", folder);
+	del = sqlite3_mprintf ("DROP TABLE '%q_bodystructure' ", folder);
 	ret = camel_db_add_to_transaction (cdb, del, ex);
 	sqlite3_free (del);
 
@@ -1751,6 +2031,11 @@ camel_db_delete_folder (CamelDB *cdb, const gchar *folder, CamelException *ex)
 	return ret;
 }
 
+/**
+ * camel_db_rename_folder:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_rename_folder (CamelDB *cdb, const gchar *old_folder, const gchar *new_folder, CamelException *ex)
 {
@@ -1789,6 +2074,11 @@ camel_db_rename_folder (CamelDB *cdb, const gchar *old_folder, const gchar *new_
 	return ret;
 }
 
+/**
+ * camel_db_camel_mir_free:
+ *
+ * Since: 2.24
+ **/
 void
 camel_db_camel_mir_free (CamelMIRecord *record)
 {
@@ -1813,12 +2103,22 @@ camel_db_camel_mir_free (CamelMIRecord *record)
 	}
 }
 
+/**
+ * camel_db_sqlize_string:
+ *
+ * Since: 2.24
+ **/
 gchar *
 camel_db_sqlize_string (const gchar *string)
 {
 	return sqlite3_mprintf ("%Q", string);
 }
 
+/**
+ * camel_db_free_sqlized_string:
+ *
+ * Since: 2.24
+ **/
 void
 camel_db_free_sqlized_string (gchar *string)
 {
@@ -1840,6 +2140,11 @@ followup_flag TEXT ,
 followup_completed_on TEXT ,
 followup_due_by TEXT ," */
 
+/**
+ * camel_db_get_column_name:
+ *
+ * Since: 2.24
+ **/
 gchar *
 camel_db_get_column_name (const gchar *raw_name)
 {
@@ -1874,6 +2179,11 @@ camel_db_get_column_name (const gchar *raw_name)
 
 }
 
+/**
+ * camel_db_migrate_vfolders_to_14:
+ *
+ * Since: 2.24
+ **/
 gint
 camel_db_migrate_vfolders_to_14 (CamelDB *cdb, const gchar *folder, CamelException *ex)
 {
@@ -1887,7 +2197,13 @@ camel_db_migrate_vfolders_to_14 (CamelDB *cdb, const gchar *folder, CamelExcepti
 	return ret;
 }
 
-gint camel_db_start_in_memory_transactions (CamelDB *cdb, CamelException *ex)
+/**
+ * camel_db_start_in_memory_transactions:
+ *
+ * Since: 2.26
+ **/
+gint
+camel_db_start_in_memory_transactions (CamelDB *cdb, CamelException *ex)
 {
 	gint ret;
 	gchar *cmd = sqlite3_mprintf ("ATTACH DATABASE ':memory:' AS %s", CAMEL_DB_IN_MEMORY_DB);
@@ -1904,7 +2220,13 @@ gint camel_db_start_in_memory_transactions (CamelDB *cdb, CamelException *ex)
 	return ret;
 }
 
-gint camel_db_flush_in_memory_transactions (CamelDB *cdb, const gchar * folder_name, CamelException *ex)
+/**
+ * camel_db_flush_in_memory_transactions:
+ *
+ * Since: 2.26
+ **/
+gint
+camel_db_flush_in_memory_transactions (CamelDB *cdb, const gchar * folder_name, CamelException *ex)
 {
 	gint ret;
 	gchar *cmd = sqlite3_mprintf ("INSERT INTO %Q SELECT * FROM %Q", folder_name, CAMEL_DB_IN_MEMORY_TABLE);
