@@ -53,10 +53,21 @@ typedef struct {
 /* Standard Camel function */
 CamelType camel_stream_vfs_get_type (void);
 
+/**
+ * CamelStreamVFSOpenMethod:
+ * CAMEL_STREAM_VFS_CREATE:
+ * 	Writable, creates new file or replaces old file.
+ * CAMEL_STREAM_VFS_APPEND:
+ * 	Writable, creates new file or appends at the end of the old file.
+ * CAMEL_STREAM_VFS_READ:
+ * 	Readable, opens existing file for reading.
+ *
+ * Since: 2.24
+ **/
 typedef enum {
-	CAMEL_STREAM_VFS_CREATE,	/* writable, creates new file or replaces old file */
-	CAMEL_STREAM_VFS_APPEND,	/* writable, creates new file or appends at the end of the old file */
-	CAMEL_STREAM_VFS_READ		/* readable, opens existing file for reading */
+	CAMEL_STREAM_VFS_CREATE,
+	CAMEL_STREAM_VFS_APPEND,
+	CAMEL_STREAM_VFS_READ
 } CamelStreamVFSOpenMethod;
 
 /* public methods */
