@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001 Ximian Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -35,7 +35,7 @@ typedef struct _CamelNNTPStream CamelNNTPStream;
 typedef enum {
 	CAMEL_NNTP_STREAM_LINE,
 	CAMEL_NNTP_STREAM_DATA,
-	CAMEL_NNTP_STREAM_EOD,	/* end of data, acts as if end of stream */
+	CAMEL_NNTP_STREAM_EOD	/* end of data, acts as if end of stream */
 } camel_nntp_stream_mode_t;
 
 struct _CamelNNTPStream {
@@ -44,10 +44,10 @@ struct _CamelNNTPStream {
 	CamelStream *source;
 
 	camel_nntp_stream_mode_t mode;
-	int state;
+	gint state;
 
-	unsigned char *buf, *ptr, *end;
-	unsigned char *linebuf, *lineptr, *lineend;
+	guchar *buf, *ptr, *end;
+	guchar *linebuf, *lineptr, *lineend;
 };
 
 struct _CamelNNTPStreamClass {
@@ -58,13 +58,12 @@ CamelType		 camel_nntp_stream_get_type	(void);
 
 CamelStream     *camel_nntp_stream_new		(CamelStream *source);
 
-
 void		 camel_nntp_stream_set_mode     (CamelNNTPStream *is, camel_nntp_stream_mode_t mode);
 
-int              camel_nntp_stream_line		(CamelNNTPStream *is, unsigned char **data, unsigned int *len);
-int 		 camel_nntp_stream_gets		(CamelNNTPStream *is, unsigned char **start, unsigned int *len);
-int 		 camel_nntp_stream_getd		(CamelNNTPStream *is, unsigned char **start, unsigned int *len);
+gint              camel_nntp_stream_line		(CamelNNTPStream *is, guchar **data, guint *len);
+gint		 camel_nntp_stream_gets		(CamelNNTPStream *is, guchar **start, guint *len);
+gint		 camel_nntp_stream_getd		(CamelNNTPStream *is, guchar **start, guint *len);
 
 G_END_DECLS
 
-#endif /* ! _CAMEL_NNTP_STREAM_H */
+#endif /* _CAMEL_NNTP_STREAM_H */
