@@ -46,8 +46,8 @@
  *
  * Returns: 0 on success; -1 on failure.
  **/
-int
-e_util_mkdir_hier (const char *path, mode_t mode)
+gint
+e_util_mkdir_hier (const gchar *path, mode_t mode)
 {
 	return g_mkdir_with_parents (path, mode);
 }
@@ -141,7 +141,7 @@ e_util_utf8_strstrcase (const gchar *haystack, const gchar *needle)
         for (p = e_util_unicode_get_utf8 (o, &unival); p && unival; p = e_util_unicode_get_utf8 (p, &unival)) {
                 gunichar sc;
                 sc = g_unichar_tolower (unival);
-                /* We have valid stripped char */
+                /* We have valid stripped gchar */
                 if (sc == nuni[0]) {
                         const gchar *q = p;
                         gint npos = 1;
@@ -162,7 +162,6 @@ e_util_utf8_strstrcase (const gchar *haystack, const gchar *needle)
         return NULL;
 }
 
-
 static gunichar
 stripped_char (gunichar ch)
 {
@@ -240,7 +239,7 @@ e_util_utf8_strstrcasedecomp (const gchar *haystack, const gchar *needle)
                 gunichar sc;
                 sc = stripped_char (unival);
                 if (sc) {
-                        /* We have valid stripped char */
+                        /* We have valid stripped gchar */
                         if (sc == nuni[0]) {
                                 const gchar *q = p;
                                 gint npos = 1;
@@ -262,11 +261,11 @@ e_util_utf8_strstrcasedecomp (const gchar *haystack, const gchar *needle)
         return NULL;
 }
 
-int
+gint
 e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2)
 {
 	gchar *folded_s1, *folded_s2;
-	int retval;
+	gint retval;
 
 	g_return_val_if_fail (s1 != NULL && s2 != NULL, -1);
 
@@ -284,6 +283,40 @@ e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2)
 	return retval;
 }
 
+/**
+ * e_util_utf8_remove_accents:
+ *
+ * Returns newly allocates string, copy of 'str', without accents.
+ *
+ * Since: 2.28
+ **/
+gchar *
+e_util_utf8_remove_accents (const gchar *str)
+{
+	gchar *res;
+	gint i, j;
+
+	if (!str)
+		return NULL;
+
+	res = g_utf8_normalize (str, -1, G_NORMALIZE_NFD);
+	if (!res)
+		return g_strdup (str);
+
+	for (i = 0, j = 0; res [i]; i++) {
+		if ((guchar)res[i] != 0xCC || res [i + 1] == 0) {
+			res [j] = res [i];
+			j++;
+		} else {
+			i++;
+		}
+	}
+
+	res [j] = 0;
+
+	return res;
+}
+
 /**
  * e_strftime:
  * @s: The string array to store the result in.
@@ -296,13 +329,13 @@ e_util_utf8_strcasecmp (const gchar *s1, const gchar *s2)
  *
  * Returns: The number of characters placed in @s.
  **/
-size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
+gsize e_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm)
 {
-	size_t ret;
+	gsize ret;
 #ifdef HAVE_LKSTRFTIME
 	ret = strftime(s, max, fmt, tm);
 #else
-	char *c, *ffmt, *ff;
+	gchar *c, *ffmt, *ff;
 
 	ffmt = g_strdup(fmt);
 	ff = ffmt;
@@ -345,11 +378,11 @@ size_t e_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
  *
  * Returns: The number of characters placed in @s.
  **/
-size_t
-e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
+gsize
+e_utf8_strftime(gchar *s, gsize max, const gchar *fmt, const struct tm *tm)
 {
-	size_t sz, ret;
-	char *locale_fmt, *buf;
+	gsize sz, ret;
+	gchar *locale_fmt, *buf;
 
 	locale_fmt = g_locale_from_utf8(fmt, -1, NULL, &sz, NULL);
 	if (!locale_fmt)
@@ -368,7 +401,7 @@ e_utf8_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 	}
 
 	if (sz >= max) {
-		char *tmp = buf + max - 1;
+		gchar *tmp = buf + max - 1;
 		tmp = g_utf8_find_prev_char(buf, tmp);
 		if (tmp)
 			sz = tmp - buf;
@@ -422,7 +455,7 @@ e_util_pthread_id (pthread_t t)
 	/* 64-bit Windows */
 	return (guint64) t.p;
 #else
-	return (int) t.p;
+	return (gint) t.p;
 #endif
 #else
 	/* Just return a checksum of the contents of the pthread_t */
@@ -458,15 +491,15 @@ e_filename_make_safe (gchar *string)
 	gchar *p, *ts;
 	gunichar c;
 #ifdef G_OS_WIN32
-	const char *unsafe_chars = " /'\"`&();|<>$%{}!\\:*?#";
+	const gchar *unsafe_chars = " /'\"`&();|<>$%{}!\\:*?#";
 #else
-	const char *unsafe_chars = " /'\"`&();|<>$%{}!#";
+	const gchar *unsafe_chars = " /'\"`&();|<>$%{}!#";
 #endif
 
 	g_return_if_fail (string != NULL);
 	p = string;
 
-	while(p && *p) {
+	while (p && *p) {
 		c = g_utf8_get_char (p);
 		ts = p;
 		p = g_utf8_next_char (p);
@@ -485,95 +518,13 @@ e_filename_make_safe (gchar *string)
 
 #include <windows.h>
 
-/* The following function is lifted from libgnome. We don't want
- * libedataserver to depend on libgnome, especially as libgnome is
- * being deprecated. This function will move to GLib, presumably, but
- * isn't there yet.
- */
+static const gchar *prefix = NULL;
+static const gchar *cp_prefix;
 
-/**
- * gnome_win32_get_prefixes:
- * @hmodule: The handle to a DLL (a HMODULE).
- * @full_prefix: Where the full UTF-8 path to the DLL's installation folder
- *               will be returned.
- * @cp_prefix: Where a system codepage version of
- *             the installation folder will be returned.
- *
- * This function looks up the installation prefix of the DLL (or EXE)
- * with handle @hmodule. The prefix using long filenames and in UTF-8
- * form is returned in @full_prefix. The prefix using short file names
- * (if present in the file system) and in the system codepage is
- * returned in @cp_prefix. To determine the installation prefix, the
- * full path to the DLL or EXE is first fetched. If the last folder
- * component in that path is called "bin", its parent folder is used,
- * otherwise the folder itself.
- *
- * If either can't be obtained, %NULL is stored. The caller should be
- * prepared to handle that.
- *
- * The returned character pointers are newly allocated and should be
- * freed with g_free when not longer needed.
- */
-static void
-get_prefixes (gpointer  hmodule,
-	      char    **full_prefix,
-	      char    **cp_prefix)
-{
-        wchar_t wcbfr[1000];
-        char cpbfr[1000];
-
-        g_return_if_fail (full_prefix != NULL);
-        g_return_if_fail (cp_prefix != NULL);
-
-        *full_prefix = NULL;
-        *cp_prefix = NULL;
-
-	if (GetModuleFileNameW ((HMODULE) hmodule, wcbfr, G_N_ELEMENTS (wcbfr))) {
-		*full_prefix = g_utf16_to_utf8 (wcbfr, -1,
-						NULL, NULL, NULL);
-		if (GetShortPathNameW (wcbfr, wcbfr, G_N_ELEMENTS (wcbfr)) &&
-		    /* Short pathnames always contain only
-		     * ASCII, I think, but just in case, be
-		     * prepared.
-		     */
-		    WideCharToMultiByte (CP_ACP, 0, wcbfr, -1,
-					 cpbfr, G_N_ELEMENTS (cpbfr),
-					 NULL, NULL))
-			*cp_prefix = g_strdup (cpbfr);
-		else if (*full_prefix)
-			*cp_prefix = g_locale_from_utf8 (*full_prefix, -1,
-							 NULL, NULL, NULL);
-	}
-
-        if (*full_prefix != NULL) {
-                gchar *p = strrchr (*full_prefix, '\\');
-                if (p != NULL)
-                        *p = '\0';
-
-                p = strrchr (*full_prefix, '\\');
-                if (p && (g_ascii_strcasecmp (p + 1, "bin") == 0))
-                        *p = '\0';
-        }
-
-        /* cp_prefix is in system codepage */
-        if (*cp_prefix != NULL) {
-                gchar *p = _mbsrchr (*cp_prefix, '\\');
-                if (p != NULL)
-                        *p = '\0';
-
-                p = _mbsrchr (*cp_prefix, '\\');
-                if (p && (g_ascii_strcasecmp (p + 1, "bin") == 0))
-                        *p = '\0';
-        }
-}
-
-static const char *prefix = NULL;
-static const char *cp_prefix;
-
-static const char *localedir;
-static const char *extensiondir;
-static const char *imagesdir;
-static const char *ui_gladedir;
+static const gchar *localedir;
+static const gchar *extensiondir;
+static const gchar *imagesdir;
+static const gchar *ui_uidir;
 
 static HMODULE hmodule;
 G_LOCK_DEFINE_STATIC (mutex);
@@ -597,14 +548,14 @@ DllMain (HINSTANCE hinstDLL,
         return TRUE;
 }
 
-char *
-e_util_replace_prefix (const char *configure_time_prefix,
-		       const char *runtime_prefix,
-		       const char *configure_time_path)
+gchar *
+e_util_replace_prefix (const gchar *configure_time_prefix,
+		       const gchar *runtime_prefix,
+		       const gchar *configure_time_path)
 {
-	char *c_t_prefix_slash = g_strconcat (configure_time_prefix, "/",
+	gchar *c_t_prefix_slash = g_strconcat (configure_time_prefix, "/",
 					      NULL);
-	char *retval;
+	gchar *retval;
 
         if (runtime_prefix &&
             g_str_has_prefix (configure_time_path, c_t_prefix_slash)) {
@@ -619,9 +570,9 @@ e_util_replace_prefix (const char *configure_time_prefix,
 	return retval;
 }
 
-static char *
-replace_prefix (const char *runtime_prefix,
-		const char *configure_time_path)
+static gchar *
+replace_prefix (const gchar *runtime_prefix,
+		const gchar *configure_time_path)
 {
 	return e_util_replace_prefix (E_DATA_SERVER_PREFIX,
 				      runtime_prefix,
@@ -631,8 +582,8 @@ replace_prefix (const char *runtime_prefix,
 static void
 setup (void)
 {
-	char *full_pfx;
-	char *cp_pfx;
+	gchar *full_pfx;
+	gchar *cp_pfx;
 
         G_LOCK (mutex);
         if (prefix != NULL) {
@@ -641,7 +592,8 @@ setup (void)
         }
 
 	/* This requires that the libedataserver DLL is installed in $bindir */
-        get_prefixes (hmodule, &full_pfx, &cp_pfx);
+	full_pfx = g_win32_get_package_installation_directory_of_module(hmodule);
+	cp_pfx = g_win32_locale_filename_from_utf8(full_pfx);
 
 	prefix = g_strdup (full_pfx);
 	cp_prefix = g_strdup (cp_pfx);
@@ -652,7 +604,7 @@ setup (void)
 	localedir = replace_prefix (cp_prefix, EVOLUTION_LOCALEDIR);
 	extensiondir = replace_prefix (prefix, E_DATA_SERVER_EXTENSIONDIR);
 	imagesdir = replace_prefix (prefix, E_DATA_SERVER_IMAGESDIR);
-	ui_gladedir = replace_prefix (prefix, E_DATA_SERVER_UI_GLADEDIR);
+	ui_uidir = replace_prefix (prefix, E_DATA_SERVER_UI_UIDIR);
 
 	G_UNLOCK (mutex);
 }
@@ -666,18 +618,18 @@ setup (void)
 }
 
 #define PRIVATE_GETTER(varbl)			\
-const char *					\
+const gchar *					\
 _libedataserver_get_##varbl (void)		\
 	GETTER_IMPL(varbl)
 
 #define PUBLIC_GETTER(varbl)			\
-const char *					\
+const gchar *					\
 e_util_get_##varbl (void)			\
 	GETTER_IMPL(varbl)
 
 PRIVATE_GETTER(extensiondir)
 PRIVATE_GETTER(imagesdir)
-PRIVATE_GETTER(ui_gladedir)
+PRIVATE_GETTER(ui_uidir)
 
 PUBLIC_GETTER(prefix)
 PUBLIC_GETTER(cp_prefix)
