@@ -175,6 +175,7 @@ ep_key_file_save (void)
 {
 	gchar *contents;
 	gchar *filename;
+	gchar *pathname;
 	gsize length = 0;
 	GError *error = NULL;
 
@@ -183,9 +184,14 @@ ep_key_file_save (void)
 
 	filename = ep_key_file_get_filename ();
 	contents = g_key_file_to_data (key_file, &length, &error);
+	pathname = g_path_get_dirname (filename);
 
-	if (!error)
+	if (!error) {
+		g_mkdir_with_parents (pathname, 0700);
 		g_file_set_contents (filename, contents, length, &error);
+	}
+	
+	g_free (pathname);
 
 	if (error != NULL) {
 		g_warning ("%s: %s", filename, error->message);
@@ -1420,7 +1426,7 @@ e_passwords_forget_password (const gchar *component_name, const gchar *key)
  * e_passwords_get_password:
  * @key: the key
  *
- * Return value: the password associated with @key, or %NULL.  Caller
+ * Returns: the password associated with @key, or %NULL.  Caller
  * must free the returned password.
  **/
 gchar *
@@ -1484,7 +1490,7 @@ e_passwords_add_password (const gchar *key, const gchar *passwd)
  *
  * Asks the user for a password.
  *
- * Return value: the password, which the caller must free, or %NULL if
+ * Returns: the password, which the caller must free, or %NULL if
  * the user cancelled the operation. *@remember will be set if the
  * return value is non-%NULL and @remember_type is not
  * E_PASSWORDS_DO_NOT_REMEMBER.
